Soundex
#######

.. image::
   https://travis-ci.org/Project-SILPA/soundex.svg?branch=master
   :target: https://travis-ci.org/Project-SILPA/soundex



.. image::
   https://coveralls.io/repos/Project-SILPA/soundex/badge.png?branch=master
  :target: https://coveralls.io/r/Project-SILPA/soundex?branch=master


Soundex is phonetic algorithm for indexing names by sound as
pronounced in English. This module implements Soundex algorithm for
Engish as well as a modified version of soundex algorithm for Indian
languages.

Details on how Soundex is implemented can be found at `Santhosh's blog
<http://thottingal.in/blog/2009/07/26/indicsoundex/>`_
